/* call_dct.c the calling function for the 2D-DCT

 * Copyright (C) 2003 -- Lesley Shannon -- University of Toronto

 * This software is available to the user without any license fee or
 * royalty on an "as is" basis with no guarantee of support.   The author 
 * and University of Toronto disclaim any and all warranties, whether 
 * express, implied or statuary, including any implied warranties or
 * merchantability or of fitness for a particular pupose.
 *
 * Only not-for-profit use of this software is permitted.  The user may
 * modify or use the source code for other not-for-profit research
 * endeavours, provided that all copyright attribution on the source code is
 * retained, and the original or modified source code is not redistributed,
 * in whole or in part, or included in or with any commerical product, except
 * by written agreement with the authors, and full and complete attribution
 * for use of the code is given in any resulting publications.
 */

/* Author: Lesley Shannon
 * Date:   January 4, 2003
 * File:   call_dct.c
 *
 * Description:
 *
 * Reads in file inputs and writes the outputs for the 2D-DCT.
 *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */



#include <stdio.h>
#include <math.h>
#include "fdctref.h"


short block[64];

char InFileName[80];
char OutFileName[80];
FILE *InFile;
FILE *OutFile;

void init_block(int flag)
{

	int i, j;
	int in_tmp;
	short tmp_val, sign;

	for (i=0; i<8; i++)
	{
		for (j=0; j<8; j++)
		{
			fscanf(InFile, "%d",&in_tmp);
			block[8*i+j] = (short)in_tmp;
		}
	}

	return;
}

/** FOR DEBUGGING ONLY **/
void print_block(void)
{
	char FileName[80];
	FILE *OutFile;

	int i, j;

	for (i=0; i<8; i++)
	{
		printf("( ");

		for (j=0; j<8; j++)
		{
			printf("%6d ", block[8*i+j]);
		}

		printf(")\n");
	}

	return;
}

void save_output(int flag)
{
	int i, j;

        printf("Printing the %d output 'block'.\n", flag);

        for(i=0; i<8; i++)
        {
                for (j=0; j<8; j++)
                {
                        fprintf(OutFile, "%5d ", block[8*i+j]);
                }
                fprintf(OutFile, " \n");
        }
        fprintf(OutFile, "\n\n");

	return;
}

void main (void)
{
	int k;

	sprintf(InFileName, "dct_in_blocks.txt");
        InFile = fopen(InFileName, "r");
        if (InFile==NULL)
        {
               	printf("Error. Unable to open file %s.\n", InFileName);
               	exit(0);
        }
        else
		printf("Reading input file %s.\n", InFileName);
        
        sprintf(OutFileName, "dct_out_blocks.txt");
        OutFile = fopen(OutFileName, "w");
        if (OutFile==NULL)
        {
                printf("Error. Unable to open file %s.\n", OutFileName);
                exit(0);
        }
        else
                printf("Opening the output file %s.\n", OutFileName);

	for (k=1; k<26; k++)
	{
		init_block(k);
		printf("DCT %d\n", k);
		/*print_block();*/

		init_fdct();
		fdct(block);

		printf("Completed DCT %d\n", k);
		/*print_block();*/
		save_output(k);
	}
	
	fclose(InFile);
        fclose(OutFile);

	return;
}

